library(Seurat)
library(biomaRt)

options(future.globals.maxSize= 1000000000000)

setwd("../")

sc10x <- readRDS("./analysis/huPr_PdPb_id_all.rds")
sc10x.fmst <- readRDS("./analysis/huPr_PdPb_id_fmst.rds")
DefaultAssay(sc10x.fmst) <- "SCT"
Idents(sc10x.fmst) <- "resolution_0.2"
sc10x.fmst <- RenameIdents(sc10x.fmst,"6"="Prostate SM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"2"="Prostate SM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"1"="Pericytes")
sc10x.fmst <- RenameIdents(sc10x.fmst,"3"="vSM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"5"="Interstitial Fibroblasts")
sc10x.fmst <- RenameIdents(sc10x.fmst,"0"="Interstitial Fibroblasts")
sc10x.fmst <- RenameIdents(sc10x.fmst,"4"="Peri-epithelial Fibroblasts")
sc10x.fmst$Populations <- Idents(sc10x.fmst)
Idents(sc10x.fmst) <- "Populations"
sc10x$pop[names(sc10x.fmst$Populations)] <- as.character(sc10x.fmst$Populations)
rm(sc10x.fmst)

as_matrix <- function(mat){
  
  tmp <- matrix(data=0L, nrow = mat@Dim[1], ncol = mat@Dim[2])
  
  row_pos <- mat@i+1
  col_pos <- findInterval(seq(mat@x)-1,mat@p[-1])+1
  val <- mat@x
  
  for (i in seq_along(val)){
    tmp[row_pos[i],col_pos[i]] <- val[i]
  }
  
  row.names(tmp) <- mat@Dimnames[[1]]
  colnames(tmp) <- mat@Dimnames[[2]]
  return(tmp)
}

count_norm <- as.data.frame(as_matrix(GetAssayData(sc10x,assay="SCT",slot="data")))
count_norm$Symbol <- rownames(count_norm)
ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl",host="https://sep2019.archive.ensembl.org")
symbol2ID <- getBM(mart = ensembl,attributes = c("external_gene_name","ensembl_gene_id"),filters="external_gene_name",values=count_norm$Symbol,uniqueRows=TRUE)
colnames(symbol2ID)[colnames(symbol2ID)=="ensembl_gene_id"] <- "Genes"
count_norm <- merge(x=count_norm,y=symbol2ID,by.x="Symbol",by.y="external_gene_name",all.x=TRUE)
count_norm$Symbol <- NULL
count_norm <- count_norm[,c(which(colnames(count_norm)=="Genes"),which(colnames(count_norm)!="Genes"))]
write.table(count_norm,'./analysis/cellphonedb_count.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$pop))
write.table(meta_data,'./analysis/cellphonedb_meta.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)
