gc()
library(Seurat)
library(RColorBrewer)
library(viridis)
library(gridExtra)
library(ggplot2)
library(qusage)
library(VennDiagram)
library(biomaRt)

setwd("../")

source("./r.scripts/sc-TissueMapper_functions.R")
source("./r.scripts/sc-TissueMapper_process.R")

sc10x <- readRDS("./analysis/huPr_PdPb_id_all.rds")
DefaultAssay(sc10x) <- "SCT"
Idents(sc10x) <- "lin"
sc10x.epi <- subset(sc10x,idents="Epithelia")
sc10x$Lineage <- sc10x$lin

postscript("./analysis/UMAP.huPr_PdPb_all.lin.eps")
DimPlot(sc10x,group.by="Lineage",reduction="umap",label=TRUE,repel=TRUE,label.size=10,pt.size=2)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()

sc10x.leu <- readRDS("./analysis/huPr_PdPb_id_leu.rds")
DefaultAssay(sc10x.leu) <- "SCT"
sc10x.leu$Lineage <- sc10x.leu$lin
sc10x.leu$Populations <- sc10x.leu$pop
Idents(sc10x.leu) <- "Populations"
sc10x.leu <- RenameIdents(sc10x.leu,"CD4+ Naive T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"CD4+ Memory/Effector T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"CD8+ Naive T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"CD8+ Memory/Effector T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Natural Killer T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Proliferating NK/T"="T Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"B"="B Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Plasma"="B Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Natural Killer"="NK Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Plasmacytoid Dendritic"="pDC Cells")
sc10x.leu <- RenameIdents(sc10x.leu,"Nonclassical Monocyte"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"TREM2+ Dendritic"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"Classical Monocyte"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"Myeloid Dendritic Type 2"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"IGSF21+ Dendritic"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"EREG+ Dendritic"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"Myeloid Dendritic Type 1"="Myeloid")
sc10x.leu <- RenameIdents(sc10x.leu,"Basophil/Mast 1"="Granulocyte")
sc10x.leu <- RenameIdents(sc10x.leu,"Basophil/Mast 2"="Granulocyte")
sc10x.leu$Groups <- Idents(sc10x.leu)
sc10x.leu$Groups <- factor(sc10x.leu$Groups,levels=c("T Cells","B Cells","NK Cells","pDC Cells","Myeloid","Granulocyte"))
Idents(sc10x.leu) <- "Groups"
sc10x.leu.t <- subset(sc10x.leu,idents="T Cells")

sc10x.leu$Populations <- factor(sc10x.leu$Populations,levels=c("CD4+ Naive T","CD4+ Memory/Effector T","CD8+ Naive T","CD8+ Memory/Effector T","Natural Killer T","Proliferating NK/T","Natural Killer","B","Plasma","Plasmacytoid Dendritic","Basophil/Mast 1","Basophil/Mast 2","Classical Monocyte","Nonclassical Monocyte","Myeloid Dendritic Type 1","Myeloid Dendritic Type 2","EREG+ Dendritic","IGSF21+ Dendritic","TREM2+ Dendritic"))
postscript("./analysis/UMAP.huPr_PdPb_leu.lin.eps")
DimPlot(sc10x.leu,group.by="Lineage",reduction="umap",label=TRUE,repel=TRUE,label.size=10,pt.size=0.1)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/UMAP.huPr_PdPb_leu.pops.eps")
DimPlot(sc10x.leu,group.by="Populations",reduction="umap",label=FALSE,repel=TRUE,label.size=5,pt.size=0.1)+theme(legend.position="right",legend.text=element_text(size=15))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/UMAP.huPr_PdPb_leu.pops.labs.eps")
DimPlot(sc10x.leu,group.by="Populations",reduction="umap",label=TRUE,repel=TRUE,label.size=5,pt.size=0.1)+theme(legend.position="right",legend.text=element_text(size=15))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/UMAP.huPr_PdPb_leu.pops.nolabs.eps")
DimPlot(sc10x.leu,group.by="Populations",reduction="umap",label=FALSE,repel=TRUE,label.size=5,pt.size=0.1)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_tcells_cytokines.eps")
DotPlot(sc10x.leu.t,group.by="Populations",features=c("IFNG","TNF","IL2","IL4","IL5","IL10","IL12A","IL12B","IL13","IL17A","IL17B","IL17C","IL17D","IL17F"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_leu_cytokines.eps")
DotPlot(sc10x.leu,group.by="Groups",features=c("IFNG","TNF","IL2","IL4","IL5","IL10","IL12A","IL12B","IL13","IL17A","IL17B","IL17C","IL17D","IL17F"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()

sc10x.fmst <- readRDS("./analysis/huPr_PdPb_id_fmst.rds")
DefaultAssay(sc10x.fmst) <- "SCT"
Idents(sc10x.fmst) <- "resolution_0.4"
sc10x.fmst <- RenameIdents(sc10x.fmst,"7"="pSM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"3"="pSM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"1"="Pericytes")
sc10x.fmst <- RenameIdents(sc10x.fmst,"4"="vSM")
sc10x.fmst <- RenameIdents(sc10x.fmst,"6"="iFib")
sc10x.fmst <- RenameIdents(sc10x.fmst,"5"="iFib")
sc10x.fmst <- RenameIdents(sc10x.fmst,"0"="iFib")
sc10x.fmst <- RenameIdents(sc10x.fmst,"2"="peFib")
sc10x.fmst$Populations <- Idents(sc10x.fmst)
Idents(sc10x.fmst) <- "Populations"
sc10x.fib <- subset(sc10x.fmst,idents=c("peFib","iFib"))
postscript("./analysis/UMAP.huPr_PdPb_fmst.pops.eps")
DimPlot(sc10x.fmst,group.by="Populations",reduction="umap",label=TRUE,repel=TRUE,label.size=10,pt.size=2)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fmst.eps")
DotPlot(sc10x.fmst,features=c("DCN","APOD","C7","ACTA2","DES","THY1","MCAM"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fib.eps")
DotPlot(sc10x.fib,features=c("DCN","APOD","PTGS2","PTGDS","MMP2","C7","CCK","PCOLCE2","GSN"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()

bph <- unique(sc10x$samples)[startsWith(unique(sc10x$samples),"BPH")]
donor <- unique(sc10x$samples)[startsWith(unique(sc10x$samples),"D")]
sc10x$Phenotype <- sc10x$samples
Idents(sc10x) <- "Phenotype"
sc10x$Phenotype[sc10x$Phenotype %in% bph] <- "BPH"
sc10x$Phenotype[sc10x$Phenotype %in% donor] <- "Donor"
Idents(sc10x) <- "Phenotype"
sc10x.fmst$Phenotype <- sc10x.fmst$samples
Idents(sc10x.fmst) <- "Phenotype"
sc10x.fmst$Phenotype[sc10x.fmst$Phenotype %in% bph] <- "BPH"
sc10x.fmst$Phenotype[sc10x.fmst$Phenotype %in% donor] <- "Donor"
Idents(sc10x.fmst) <- "Phenotype"
sc10x.fib$Phenotype <- sc10x.fib$samples
Idents(sc10x.fib) <- "Phenotype"
sc10x.fib$Phenotype[sc10x.fib$Phenotype %in% bph] <- "BPH"
sc10x.fib$Phenotype[sc10x.fib$Phenotype %in% donor] <- "Donor"
Idents(sc10x.fib) <- "Phenotype"
sc10x.donor <- subset(sc10x,idents="Donor")
sc10x.fmst.donor <- subset(sc10x.fmst,idents="Donor")
sc10x.fib.donor <- subset(sc10x.fib,idents="Donor")
sc10x.fmst$Phenotypes <- paste0(sc10x.fmst$Phenotype," ",sc10x.fmst$Populations)
sc10x.fmst.donor$Populations <- factor(sc10x.fmst.donor$Populations)
Idents(sc10x.fmst) <- "Phenotypes"
sc10x.fmst@active.ident <- factor(sc10x.fmst@active.ident,levels=c("Donor iFib","BPH iFib","Donor peFib","BPH peFib","Donor vSM","BPH vSM","Donor Pericytes","BPH Pericytes","Donor pSM","BPH pSM"))
sc10x.fmst$Phenotypes <- Idents(sc10x.fmst)
sc10x.fib$Phenotypes <- paste0(sc10x.fib$Phenotype," ",sc10x.fib$Populations)
sc10x.fib.donor$Populations <- factor(sc10x.fib.donor$Populations)
Idents(sc10x.fib) <- "Phenotypes"
sc10x.fib@active.ident <- factor(sc10x.fib@active.ident,levels=c("Donor iFib","BPH iFib","Donor peFib","BPH peFib"))

postscript("./analysis/UMAP.huPr_PdPb_all.donor.lin.eps")
DimPlot(sc10x.donor,group.by="Lineage",reduction="umap",label=TRUE,repel=TRUE,label.size=10,pt.size=2)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/UMAP.huPr_PdPb_fmst.donor.pops.eps")
DimPlot(sc10x.fmst.donor,group.by="Populations",reduction="umap",label=TRUE,repel=TRUE,label.size=10,pt.size=2)+theme(legend.position="none")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fmst.donor.eps")
DotPlot(sc10x.fmst.donor,group.by="Populations",features=c("DCN","APOD","C7","ACTA2","DES","THY1","MCAM"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fib.donor.eps")
DotPlot(sc10x.fib.donor,group.by="Populations",features=c("DCN","APOD","PTGS2","PTGDS","MMP2","C7","CCK","PCOLCE2","GSN"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fmst_pheno_unique.eps")
DotPlot(sc10x.fmst,group.by="Phenotypes",features=c("IL6","CCL2","HLA-DRA","CXCL13","AR","RSPO3","CCN2","SFRP4","COL4A1","KCNJ8","TNC","DES","LBH","ADRA2A"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()

postscript(paste0("./analysis/DotPlot.huPr_PdPb_fib_pheono_page4.eps"))
DotPlot(sc10x.fib,features=c("PAGE4"),cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
genes.wnt <- c("SFRP1","SFRP2","SFRP4","SFRP5",'WNT10A',
               "WNT11","WNT16","WNT2","WNT2B","WNT3A",
               "WNT4","WNT5A","WNT5A-AS1","WNT5B",
               "WNT6","WNT7A","WNT7B","WNT9A","WIF1",
               "AXIN2","FZD1","FZD10","FZD2","FZD3",
               "FZD4","FZD5","FZD6","FZD7","FZD8",
               "FZD9","DKK1","APC","CTNNB1","DVL1",
               "LEF1","PORCN")
postscript("./analysis/DotPlot.huPr_PdPb_fib.donor_wnt.eps")
DotPlot(sc10x.fib.donor,group.by="Populations",features=genes.wnt,cols=rev(heat.colors(2)),assay="SCT")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fmst.donor_wnt.eps")
DotPlot(sc10x.fmst.donor,group.by="Populations",features=genes.wnt,cols=rev(heat.colors(2)),assay="SCT")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/Heatmap.huPr_PdPb_fib.donor_wnt.eps")
DoHeatmap(sc10x.fib.donor,group.by="Populations",features=genes.wnt,assay = "SCT")
dev.off()
genes.tgfb <- c("BMP2","BMP4","BMP7","MIS","INHBA",
                "TGFB1","TGFB2","TGFB3","TGFBR1","TGFBR2",
                "TGFBR3")
postscript("./analysis/DotPlot.huPr_PdPb_fib.donor_tgfb.eps")
DotPlot(sc10x.fib.donor,group.by="Populations",features=genes.tgfb,cols=rev(heat.colors(2)),assay="SCT")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
postscript("./analysis/DotPlot.huPr_PdPb_fmst.donor_tgfb.eps")
DotPlot(sc10x.fmst.donor,group.by="Populations",features=genes.tgfb,cols=rev(heat.colors(2)),assay="SCT")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
genes.wnts <- c(rownames(sc10x.fib.donor)[startsWith(rownames(sc10x.fib.donor),"WNT")],rownames(sc10x.fib.donor)[startsWith(rownames(sc10x.fib.donor),"RSPO")])
sc10x.fib.donor <- AddModuleScore(sc10x.fib.donor,features=genes.wnts,name="WNT_Score",assay="SCT",nbin=15)
postscript("./analysis/DotPlot.huPr_PdPb_fib.donor_wnt.score.eps")
DotPlot(sc10x.fib.donor,group.by="Populations",features="WNT_Score1",cols=rev(heat.colors(2)),assay="SCT")+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()
sc10x.fib <- AddModuleScore(sc10x.fib,features=genes.wnts,name="WNT_Score",assay="SCT",nbin=15)
postscript("./analysis/DotPlot.huPr_PdPb_fib_pheno_wnt.score.eps")
DotPlot(sc10x.fib,features="WNT_Score1",cols=rev(heat.colors(2)))+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40))
dev.off()

write.table(prop.table(table(sc10x$pop,sc10x$samples),2),file=paste0("./analysis/PopTable.huPr_PdPb_all.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
write.table(prop.table(table(sc10x.leu$Lineage,sc10x.leu$samples),2),file=paste0("./analysis/PopTable.huPr_PdPb_leu_lin.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
write.table(prop.table(table(sc10x.leu$Populations,sc10x.leu$samples),2),file=paste0("./analysis/PopTable.huPr_PdPb_leu_pops.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
write.table(prop.table(table(sc10x.fmst$Populations,sc10x.fmst$samples),2),file=paste0("./analysis/PopTable.huPr_PdPb_fmst.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")
Idents(sc10x) <- "lin"
sc10x <- RenameIdents(sc10x,"Lymphoid"="Leukocyte")
sc10x <- RenameIdents(sc10x,"Myeloid"="Leukocyte")
sc10x <- RenameIdents(sc10x,"Granulocyte"="Leukocyte")
sc10x$Groups <- Idents(sc10x)
sc10x$Groups <- factor(sc10x$Groups,levels=c(as.character(unique(sc10x$Groups)),as.character(unique(sc10x.fmst$Populations))))
sc10x$Groups[names(sc10x.fmst$Populations)] <- as.character(sc10x.fmst$Populations)
Idents(sc10x) <- "Groups"
sc10x$Groups <- factor(sc10x$Groups)
write.table(prop.table(table(sc10x$Groups,sc10x$samples),2),file=paste0("./analysis/PopTable.huPr_PdPb_all.groups.csv"),row.names=TRUE,col.names=NA,append=FALSE,sep=",")

deg.all <- FindAllMarkers(sc10x,assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
write.table(deg.all,file=paste0("./analysis/DEG.huPr_PdPb_all.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")
Idents(sc10x.fmst.donor) <- "Populations"
deg.fmst <- FindAllMarkers(sc10x.fmst.donor,assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
write.table(deg.fmst,file=paste0("./analysis/DEG.huPr_PdPb_fmst.donor.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")
Idents(sc10x.fib.donor) <- "Populations"
deg.fib <- FindAllMarkers(sc10x.fib.donor,assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
write.table(deg.fib,file=paste0("./analysis/DEG.huPr_PdPb_fib.donor.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")
deg.leu <- FindAllMarkers(sc10x.leu,assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
write.table(deg.leu,file=paste0("./analysis/DEG.huPr_PdPb_leu.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")

Idents(sc10x.fmst) <- "Populations"
for (i in unique(sc10x.fmst$Populations)){
  sc10x.temp <- subset(sc10x.fmst,idents=i)
  sc10x.temp$Phenotype <- sc10x.temp$samples
  Idents(sc10x.temp) <- "Phenotype"
  sc10x.temp$Phenotype[sc10x.temp$Phenotype %in% bph] <- "BPH"
  sc10x.temp$Phenotype[sc10x.temp$Phenotype %in% donor] <- "Donor"
  Idents(sc10x.temp) <- "Phenotype"
  deg.temp <- FindAllMarkers(sc10x.temp,assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
  write.table(deg.temp,file=paste0("./analysis/DEG.huPr_PdPb_",gsub(" ","",i),"_phenotype.0.25.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")
  rm(sc10x.temp)
  rm(deg.temp)
}
rm(i)

gene.set.c5.bp <- read.gmt("/work/urology/ghenry/RNA-Seq/SingleCell/ANALYSIS/REF/genesets_c5.go.bp.v7.2.symbols.gmt")
neg <- names(gene.set.c5.bp)[grepl("NEGATIVE",names(gene.set.c5.bp))]
neg <- neg[! neg %in% names(gene.set.c5.bp)[grepl("GRAM_NEGATIVE",names(gene.set.c5.bp))]]
gene.set.c5.bp <- gene.set.c5.bp[! names(gene.set.c5.bp) %in% neg]
rm(neg)
results <- scQuSAGE(sc10x.fib.donor,gs=gene.set.c5.bp,save=FALSE,type="lg",id="Populations",ds=0,nm="fib",print="0")
results.cor.c5.bp <- results[[2]]
results.clust.c5.bp <- results[[3]]
rm(results)
write.table(results.cor.c5.bp,file=paste0("./analysis/CorResults.huPr_PdPb_fib.go_bp.fib.donor.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")

Idents(sc10x.fib) <- "Populations"
for (i in unique(sc10x.fib$Populations)){
  sc10x.temp <- subset(sc10x.fib,idents=i)
  sc10x.temp$Phenotype <- sc10x.temp$samples
  Idents(sc10x.temp) <- "Phenotype"
  sc10x.temp$Phenotype[sc10x.temp$Phenotype %in% bph] <- "BPH"
  sc10x.temp$Phenotype[sc10x.temp$Phenotype %in% donor] <- "Donor"
  Idents(sc10x.temp) <- "Phenotype"
  results <- scQuSAGE(sc10x.temp,gs=gene.set.c5.bp,save=FALSE,type="lg",id="Phenotype",ds=0,nm=gsub(" ","",i),print="0")
  assign(paste0("results.cor.c5.bp.",i),results[[2]])
  write.table(results[[2]],file=paste0("./analysis/CorResults.huPr_PdPb_phenotype_",gsub(" ","",i),".go_bp.fib.csv"),row.names=FALSE,col.names=TRUE,append=FALSE,sep=",")
  rm(results)
  rm(sc10x.temp)
}
rm(i)
path.pefib <- as.character(results.cor.c5.bp.peFib$pathway.name[!is.na(results.cor.c5.bp.peFib$FDR) & results.cor.c5.bp.peFib$FDR <= 0.05 & results.cor.c5.bp.peFib$log.fold.change > 0 & results.cor.c5.bp.peFib$Cluster == "Cluster_BPH"])
path.ifib <- as.character(results.cor.c5.bp.iFib$pathway.name[!is.na(results.cor.c5.bp.iFib$FDR) & results.cor.c5.bp.iFib$FDR <= 0.05 & results.cor.c5.bp.iFib$log.fold.change > 0 & results.cor.c5.bp.iFib$Cluster == "Cluster_BPH"])
venn.diagram(list(path.pefib,path.ifib),"./analysis/Venn.huPr_PdPb_fib.c5_bp.BPH.eps",height=7500,width=7500,fill=viridis(2),alpha=c(0.5,0.5),cex=2,cat.fontface=1.5,category.names=c("peFib","iFib"),main="Pathways Significantly up in BPH vs Donor",main.cex=2)
path.fib.share <- intersect(path.pefib,path.ifib)
path.pefib.unique <- setdiff(path.pefib,path.ifib)
path.ifib.unique <- setdiff(path.ifib,path.pefib)
write.table(path.fib.share,file=paste0("./analysis/Path.huPr_PdPb_fib.share_phenotype.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")
write.table(path.pefib.unique,file=paste0("./analysis/Path.huPr_PdPb_pefib.unique_phenotype.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")
write.table(path.ifib.unique,file=paste0("./analysis/Path.huPr_PdPb_ifib.unique_phenotype.csv"),row.names=FALSE,col.names=FALSE,append=FALSE,sep=",")

Idents(sc10x.fmst) <- "Populations"
sc10x$pop[names(sc10x.fmst$Populations)] <- as.character(sc10x.fmst$Populations)
as_matrix <- function(mat){
  
  tmp <- matrix(data=0L, nrow = mat@Dim[1], ncol = mat@Dim[2])
  
  row_pos <- mat@i+1
  col_pos <- findInterval(seq(mat@x)-1,mat@p[-1])+1
  val <- mat@x
  
  for (i in seq_along(val)){
    tmp[row_pos[i],col_pos[i]] <- val[i]
  }
  
  row.names(tmp) <- mat@Dimnames[[1]]
  colnames(tmp) <- mat@Dimnames[[2]]
  return(tmp)
}
count_norm <- as.data.frame(as_matrix(GetAssayData(sc10x,assay="SCT",slot="data")))
count_norm$Symbol <- rownames(count_norm)
ensembl <- useMart("ensembl",dataset="hsapiens_gene_ensembl",host="https://sep2019.archive.ensembl.org")
symbol2ID <- getBM(mart = ensembl,attributes = c("external_gene_name","ensembl_gene_id"),filters="external_gene_name",values=count_norm$Symbol,uniqueRows=TRUE)
symbol2ID <- symbol2ID[!duplicated(symbol2ID$external_gene_name),]
colnames(symbol2ID)[colnames(symbol2ID)=="ensembl_gene_id"] <- "Genes"
count_norm <- merge(x=count_norm,y=symbol2ID,by.x="Symbol",by.y="external_gene_name",all.x=TRUE)
count_norm$Symbol <- NULL
count_norm <- count_norm[,c(which(colnames(count_norm)=="Genes"),which(colnames(count_norm)!="Genes"))]
write.table(count_norm,'./analysis/cellphonedb_count.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

sc10x$lin <- factor(sc10x$lin,levels=c("Fibroblast","Smooth Muscle","Endothelia","Epithelia","Myeloid","Granulocyte","Lymphoid"))
meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$lin))
write.table(meta_data,'./analysis/cellphonedb_meta_lin.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

Idents(sc10x) <- "pop"
sc10x <- RenameIdents(sc10x,"B"="B Cells")
sc10x <- RenameIdents(sc10x,"Plasma"="B Cells")
sc10x <- RenameIdents(sc10x,"CD4+ Naive T"="T Cells")
sc10x <- RenameIdents(sc10x,"CD4+ Memory/Effector T"="T Cells")
sc10x <- RenameIdents(sc10x,"Natural Killer T"="T Cells")
sc10x <- RenameIdents(sc10x,"Proliferating NK/T"="T Cells")
sc10x <- RenameIdents(sc10x,"CD8+ Memory/Effector T"="T Cells")
sc10x <- RenameIdents(sc10x,"CD8+ Naive T"="T Cells")
sc10x <- RenameIdents(sc10x,"Natural Killer"="NK Cells")
sc10x <- RenameIdents(sc10x,"Plasmacytoid Dendritic"="pDC")
sc10x <- RenameIdents(sc10x,"Basophil/Mast 1"="Granulocyte")
sc10x <- RenameIdents(sc10x,"Basophil/Mast 2"="Granulocyte")
sc10x <- RenameIdents(sc10x,"Nonclassical Monocyte"="Monocyte")
sc10x <- RenameIdents(sc10x,"TREM2+ Dendritic"="DC")
sc10x <- RenameIdents(sc10x,"Classical Monocyte"="Monocyte")
sc10x <- RenameIdents(sc10x,"Myeloid Dendritic Type 2"="DC")
sc10x <- RenameIdents(sc10x,"IGSF21+ Dendritic"="DC")
sc10x <- RenameIdents(sc10x,"EREG+ Dendritic"="DC")
sc10x <- RenameIdents(sc10x,"Myeloid Dendritic Type 1"="DC")
sc10x$Groups <- Idents(sc10x)
sc10x$Groups <- factor(sc10x$Groups,levels=c("peFib","iFib","pSM","vSM","Pericytes","Endothelia","BE","Hillock","Club","LE","Monocyte","DC","Granulocyte","T Cells","NK Cells","B Cells","pDC"))
Idents(sc10x) <- "Groups"
meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$Groups))
write.table(meta_data,'./analysis/cellphonedb_meta_group.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

sc10x$Split <- sc10x$lin
sc10x$Split <- factor(sc10x$Split,levels=c("Fibroblast","Smooth Muscle","peFib","iFib","pSM","vSM","Pericytes","Endothelia","BE","Hillock","Club","LE","Myeloid","Granulocyte","Lymphoid"))
sc10x$Split[names(sc10x.fmst$Populations)] <- as.character(sc10x.fmst$Populations)
sc10x$Split[names(sc10x.epi$pop)] <- as.character(sc10x.epi$pop)
sc10x$Split <- factor(sc10x$Split,levels=c("Peri-epithelial Fibroblasts","Interstitial Fibroblasts","Prostate SM","vSM","Pericytes","Endothelia","BE","Hillock","Club","LE","Myeloid","Granulocyte","Lymphoid"))
meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$Split))
write.table(meta_data,'./analysis/cellphonedb_meta_split.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

sc10x$Split2 <- sc10x$lin
sc10x$Split2 <- factor(sc10x$Split2,levels=c("Fibroblast","Smooth Muscle","peFib","iFib","pSM","vSM","Pericytes","Endothelia","Epithelia","Myeloid","Granulocyte","Lymphoid"))
sc10x$Split2[names(sc10x.fmst$Populations)] <- as.character(sc10x.fmst$Populations)
sc10x$Split2 <- factor(sc10x$Split2,levels=c("peFib","iFib","pSM","vSM","Pericytes","Endothelia","Epithelia","Myeloid","Granulocyte","Lymphoid"))
meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$Split2))
write.table(meta_data,'./analysis/cellphonedb_meta_split2.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)
Idents(sc10x) <- "Split2"
sc10x_fib.epi <- subset(sc10x,idents=c("peFib","iFib","Epithelia"))
for (i in c("FGF2", "FGFR1","IGF1","IGF1R","COL1A1","ITGA2","WNT2","FZD1","WNT4","BMP7","PTPRK","MET","HGF","WNT7B","FZD10","EGFR","NRG1","HBEGF")){
  postscript(paste0("./analysis/VlnPlot.huPr_PdPb_fib|epi_",tolower(i),".eps"))
  plot(VlnPlot(sc10x_fib.epi,features=i,pt.size=0)+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40)))
  dev.off()
}
sc10x_fib.endo <- subset(sc10x,idents=c("peFib","iFib","Endothelia"))
for (i in c("TGFB1","TGFB2","TGFBR3","FGF2","FGFR1","VEGFA","KDR","FLT1","WNT2","FZD4","SEMA3E","PLXND1","CXCL1","ACKR1")){
  postscript(paste0("./analysis/VlnPlot.huPr_PdPb_fib|endo_",tolower(i),".eps"))
  plot(VlnPlot(sc10x_fib.endo,features=i,pt.size=0)+theme(plot.title=element_text(size=50),axis.text.x=element_text(size=25,angle=45,hjust=1),axis.text.y=element_text(size=25),axis.title.x=element_text(size=40),axis.title.y=element_text(size=40)))
  dev.off()
}

sc10x$pop <- factor(sc10x$pop,levels=c("peFib","iFib","pSM","vSM","Pericytes","Endothelia","BE","Hillock","Club","LE","Classical Monocyte","Nonclassical Monocyte","Myeloid Dendritic Type 1","Myeloid Dendritic Type 2","EREG+ Dendritic","IGSF21+ Dendritic","TREM2+ Dendritic","Basophil/Mast 1","Basophil/Mast 2","CD4+ Naive T","CD4+ Memory/Effector T","CD8+ Naive T","CD8+ Memory/Effector T","Natural Killer T","Proliferating NK/T","Natural Killer","B","Plasma","Plasmacytoid Dendritic"))
Idents(sc10x) <- "pop"
meta_data <- data.frame(Cell=colnames(sc10x),cell_type=as.character(sc10x$pop))
write.table(meta_data,'./analysis/cellphonedb_meta_pop.txt',sep='\t',quote=FALSE,row.names=FALSE,col.names=TRUE)

load("./analysis/sc10x.raw.RData")
filter <- data.frame(raw=unlist(counts.cell.raw),umi=unlist(counts.cell.filtered.1umi),mito=unlist(counts.cell.filtered.2mito),ribo=unlist(counts.cell.filtered.3ribo),gene=unlist(counts.cell.filtered.4gene),stress=c(unlist(counts.cell.destress)[1:12],"-",unlist(counts.cell.destress)[13:19]))
write.table(filter,'./analysis/cells.txt',sep='\t',quote=FALSE,row.names=TRUE,col.names=NA)
