gc()
library(Seurat)
library(SingleR)
library(RColorBrewer)
library(viridis)
library(gridExtra)
library(ggplot2)
library(corrplot)

setwd("../")

ortholog <- read.delim("/work/urology/ghenry/RNA-Seq/SingleCell/ANALYSIS/REF/genesets_Ensemble.mus-hum_GRCm38.p6.txt")

sc10x.human <- readRDS("../huPr_PdPb/analysis/huPr_PdPb_id_fmst.rds")
DefaultAssay(sc10x.human) <- "SCT"
bph <- unique(sc10x.human$samples)[startsWith(unique(sc10x.human$samples),"BPH")]
donor <- unique(sc10x.human$samples)[startsWith(unique(sc10x.human$samples),"D")]
sc10x.human$phenotype <- sc10x.human$samples
Idents(sc10x.human) <- "phenotype"
sc10x.human$phenotype[sc10x.human$phenotype %in% bph] <- "BPH"
sc10x.human$phenotype[sc10x.human$phenotype %in% donor] <- "Donor"
Idents(sc10x.human) <- "phenotype"
sc10x.human <- subset(sc10x.human,idents="Donor")
Idents(sc10x.human) <- "resolution_0.2"
sc10x.human <- RenameIdents(sc10x.human,"6"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"7"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"2"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"1"="Pericyte")
sc10x.human <- RenameIdents(sc10x.human,"3"="vSM")
sc10x.human <- RenameIdents(sc10x.human,"5"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"0"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"4"="Fib_APODp")
sc10x.human$ids <- Idents(sc10x.human)
sc10x.human.fib <- subset(sc10x.human,idents=c("Fib_APODp","Fib_APODn"))
sc10x.human.fib <- sc10x.human
sc10x.human.fib <- as.SingleCellExperiment(sc10x.human.fib,assay="SCT")
rownames(sc10x.human.fib) <- ortholog$Gene.name[match(rownames(sc10x.human.fib),ortholog$Human.gene.name)]
sc10x.human <- as.SingleCellExperiment(sc10x.human,assay="SCT")
rownames(sc10x.human) <- ortholog$Gene.name[match(rownames(sc10x.human),ortholog$Human.gene.name)]

sc10x.mouse <- readRDS("./analysis/muPrUr_id_fmst.rds")
DefaultAssay(sc10x.mouse) <- "SCT"
Idents(sc10x.mouse) <- "resolution_0.1"
sc10x.mouse <- RenameIdents(sc10x.mouse,"4"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"2"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"3"="Wnt2")
sc10x.mouse <- RenameIdents(sc10x.mouse,"0"="Lgr5")
sc10x.mouse <- RenameIdents(sc10x.mouse,"1"="C3")
sc10x.mouse$id <- Idents(sc10x.mouse)
sc10x.mouse.fib <- subset(sc10x.mouse,idents=c("C3","Lgr5","Wnt2"))
sc10x.mouse.fib <- sc10x.mouse
sc10x.mouse.fib <- as.SingleCellExperiment(sc10x.mouse.fib,assay="RNA")
sc10x.mouse <- as.SingleCellExperiment(sc10x.mouse,assay="RNA")

common <- intersect(rownames(sc10x.mouse.fib),rownames(sc10x.human.fib))
sc10x.mouse.fib <- sc10x.mouse.fib[common,]
sc10x.human.fib <- sc10x.human.fib[common,]
rm(common)
common <- intersect(rownames(sc10x.mouse),rownames(sc10x.human))
sc10x.mouse <- sc10x.mouse[common,]
sc10x.human <- sc10x.human[common,]
rm(common)

singler <- SingleR(sc10x.mouse.fib,ref=sc10x.human.fib,clusters=sc10x.mouse.fib$id,labels=sc10x.human.fib$ids,de.method="wilcox",BPPARAM=BiocParallel::MulticoreParam(workers=20))

singler <- SingleR(sc10x.human.fib,ref=sc10x.mouse.fib,clusters=sc10x.human.fib$ids,labels=sc10x.mouse.fib$id,de.method="wilcox",BPPARAM=BiocParallel::MulticoreParam(workers=20))

singler <- SingleR(sc10x.mouse,ref=sc10x.human,clusters=sc10x.mouse$id,labels=sc10x.human$ids,de.method="wilcox",BPPARAM=BiocParallel::MulticoreParam(workers=20))

singler <- SingleR(sc10x.human,ref=sc10x.mouse,clusters=sc10x.human$ids,labels=sc10x.mouse$id,de.method="wilcox",BPPARAM=BiocParallel::MulticoreParam(workers=20))

plot <- plotScoreHeatmap(singler,show.labels=FALSE,show.pruned=FALSE,show_colnames=TRUE,cluster_cols=TRUE,scores.use)
jpeg("./analysis/ScoreHeatmap.muhu.jpg",width=1000,height=1000)
print(plot)
dev.off()








ortholog <- ortholog[order(ortholog[,"Human.gene.name"]),]
ortholog <- ortholog[!duplicated(ortholog$Human.gene.name),]

sc10x.mouse <- readRDS("./analysis/muPrUr_id_fmst.rds")
DefaultAssay(sc10x.mouse) <- "SCT"
sc10x.human <- readRDS("../huPr_PdPb/analysis/huPr_PdPb_id_fmst.rds")
DefaultAssay(sc10x.human) <- "SCT"

genes.mouse <- rownames(sc10x.mouse)
genes.human <- rownames(sc10x.human)
genes.mouse.filtered <- genes.mouse[genes.mouse %in% ortholog$Gene.name]
genes.human.filtered <- genes.human[genes.human %in% ortholog$Human.gene.name]
genes.mouse.filtered.humanified <- ortholog$Human.gene.name[match(genes.mouse.filtered,ortholog$Gene.name)]
genes.mouse.filtered.humanified <- genes.mouse.filtered.humanified[genes.mouse.filtered.humanified %in% genes.human.filtered]
genes.human.filtered <- genes.human.filtered[genes.human.filtered %in% genes.mouse.filtered.humanified]
genes.mouse.filtered <- ortholog$Gene.name[match(genes.mouse.filtered.humanified,ortholog$Human.gene.name)]
ortholog <- ortholog[ortholog$Gene.name %in% genes.mouse.filtered,]
ortholog <- ortholog[ortholog$Human.gene.name %in% genes.human.filtered,]

Idents(sc10x.mouse) <- "resolution_0.1"
sc10x.mouse <- RenameIdents(sc10x.mouse,"4"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"2"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"3"="Wnt2")
sc10x.mouse <- RenameIdents(sc10x.mouse,"0"="Lgr5")
sc10x.mouse <- RenameIdents(sc10x.mouse,"1"="C3")
sc10x.mouse$id <- Idents(sc10x.mouse)
sc10x.mouse.fib <- subset(sc10x.mouse,idents=c("C3","Lgr5","Wnt2"))
data.mouse.fib <- as.data.frame(AverageExpression(sc10x.mouse.fib,assays="SCT",slot="scale.data")$SCT)
data.mouse.fib <- data.mouse.fib[rownames(data.mouse.fib) %in% genes.mouse.filtered,]
rownames(data.mouse.fib) <- ortholog$Human.gene.name[match(rownames(data.mouse.fib),ortholog$Gene.name)]
data.mouse.fib <- data.mouse.fib[ortholog$Human.gene.name,]

Idents(sc10x.human) <- "resolution_0.2"
sc10x.human <- RenameIdents(sc10x.human,"6"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"7"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"2"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"1"="Pericyte")
sc10x.human <- RenameIdents(sc10x.human,"3"="vSM")
sc10x.human <- RenameIdents(sc10x.human,"5"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"0"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"4"="Fib_APODp")
sc10x.human$ids <- Idents(sc10x.human)
sc10x.human.fib <- subset(sc10x.human,idents=c("Fib_APODp","Fib_APODn"))
data.human.fib <- as.data.frame(AverageExpression(sc10x.human.fib,assays="SCT",slot="scale.data")$SCT)
data.human.fib <- data.human.fib[rownames(data.human.fib) %in% genes.human.filtered,]
data.human.fib <- data.human.fib[ortholog$Human.gene.name,]

correlation.fib <- cor(data.mouse.fib,data.human.fib,use="complete.obs")

hvg.mouse <- FindVariableFeatures(sc10x.mouse.fib,nfeatures=5000,selection.method="vst",assay="RNA")
hvg.mouse <- VariableFeatures(hvg.mouse,assay="RNA")
#hvg.mouse <- sc10x.mouse@assays$SCT@var.features
hvg.mouse <- hvg.mouse[hvg.mouse %in% genes.mouse.filtered]
hvg.mouse <- ortholog$Human.gene.name[match(hvg.mouse,ortholog$Gene.name)]
hvg.mouse <- hvg.mouse[hvg.mouse %in% genes.human.filtered]
hvg.human <- FindVariableFeatures(sc10x.human.fib,nfeatures=5000,selection.method="vst",assay="RNA")
hvg.human <- VariableFeatures(hvg.human,assay="RNA")
#hvg.human <- sc10x.human@assays$SCT@var.features
hvg.human <- hvg.human[hvg.human %in% ortholog$Human.gene.name]
data.mouse.fib.hvg.human <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg.human,]
data.human.fib.hvg.human <- data.human.fib[rownames(data.human.fib) %in% hvg.human,]
correlation.fib.hvg.human <- cor(data.mouse.fib.hvg.human,data.human.fib.hvg.human,use="complete.obs")

data.mouse.fib.hvg.mouse <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg.mouse,]
data.human.fib.hvg.mouse <- data.human.fib[rownames(data.human.fib) %in% hvg.mouse,]
correlation.fib.hvg.mouse <- cor(data.mouse.fib.hvg.mouse,data.human.fib.hvg.mouse,use="complete.obs")

hvg <- hvg.human[hvg.human %in% hvg.mouse]
data.mouse.fib.hvg <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg,]
data.human.fib.hvg <- data.human.fib[rownames(data.human.fib) %in% hvg,]
correlation.fib.hvg <- cor(data.mouse.fib.hvg,data.human.fib.hvg,use="complete.obs")

deg.human.apodP <- FindMarkers(sc10x.human.fib,ident.1="Fib_APODp",ident.2="Fib_APODn",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.human.apodN <- FindMarkers(sc10x.human.fib,ident.1="Fib_APODn",ident.2="Fib_APODp",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)

deg.human <- c(rownames(deg.human.apodP)[deg.human.apodP$p_val_adj<=0.05],rownames(deg.human.apodN)[deg.human.apodN$p_val_adj<=0.05])
data.mouse.fib.deg.human <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.human,]
data.human.fib.deg.human <- data.human.fib[rownames(data.human.fib) %in% deg.human,]
correlation.fib.deg.human <- cor(data.mouse.fib.deg.human,data.human.fib.deg.human,use="complete.obs")

deg.human.2fc <- c(rownames(deg.human.apodP)[deg.human.apodP$p_val_adj<=0.05 & deg.human.apodP$avg_log2FC>1],rownames(deg.human.apodN)[deg.human.apodN$p_val_adj<=0.05 & deg.human.apodN$avg_log2FC>1])
data.mouse.fib.deg.human.2fc <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.human.2fc,]
data.human.fib.deg.human.2fc <- data.human.fib[rownames(data.human.fib) %in% deg.human.2fc,]
correlation.fib.deg.human.2fc <- cor(data.mouse.fib.deg.human.2fc,data.human.fib.deg.human.2fc,use="complete.obs")

deg.mouse.fib1 <- FindMarkers(sc10x.mouse.fib,ident.1="C3",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.mouse.fib2 <- FindMarkers(sc10x.mouse.fib,ident.1="Lgr5",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.mouse.fib3 <- FindMarkers(sc10x.mouse.fib,ident.1="Wnt2",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)

deg.mouse <- c(rownames(deg.mouse.fib1)[deg.mouse.fib1$p_val_adj<=0.05],rownames(deg.mouse.fib2)[deg.mouse.fib2$p_val_adj<=0.05],rownames(deg.mouse.fib3)[deg.mouse.fib3$p_val_adj<=0.05])
deg.mouse <- deg.mouse[deg.mouse %in% genes.mouse.filtered]
deg.mouse <- ortholog$Human.gene.name[match(deg.mouse,ortholog$Gene.name)]
data.mouse.fib.deg.mouse <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.mouse,]
data.human.fib.deg.mouse <- data.human.fib[rownames(data.human.fib) %in% deg.mouse,]
correlation.fib.deg.mouse <- cor(data.mouse.fib.deg.mouse,data.human.fib.deg.mouse,use="complete.obs")

deg.mouse.2fc <- c(rownames(deg.mouse.fib1)[deg.mouse.fib1$p_val_adj<=0.05 & deg.mouse.fib1$avg_log2FC>1],rownames(deg.mouse.fib2)[deg.mouse.fib2$p_val_adj<=0.05 & deg.mouse.fib2$avg_log2FC>1],rownames(deg.mouse.fib3)[deg.mouse.fib3$p_val_adj<=0.05 & deg.mouse.fib3$avg_log2FC>1])
deg.mouse.2fc <- deg.mouse.2fc[deg.mouse.2fc %in% genes.mouse.filtered]
deg.mouse.2fc <- ortholog$Human.gene.name[match(deg.mouse.2fc,ortholog$Gene.name)]
data.mouse.fib.deg.mouse.2fc <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.mouse.2fc,]
data.human.fib.deg.mouse.2fc <- data.human.fib[rownames(data.human.fib) %in% deg.mouse.2fc,]
correlation.fib.deg.mouse.2fc <- cor(data.mouse.fib.deg.mouse.2fc,data.human.fib.deg.mouse.2fc,use="complete.obs")

jpeg("./analysis/Corr.muhu_fib_all.jpg",width=1000,height=1000)
corrplot(t(correlation.fib),method="color",tl.srt=45,tl.col="black",title="All Genes (14,435)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg.human),method="color",tl.srt=45,tl.col="black",title="Human HVG (3,117)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg.mouse),method="color",tl.srt=45,tl.col="black",title="Mouse HVG (3,454)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_sharedHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg),method="color",tl.srt=45,tl.col="black",title="Shared HVG (1,691)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huDEG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.human),method="color",tl.srt=45,tl.col="black",title="Human All DEGs (1,343)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huDEG2fc.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.human.2fc),method="color",tl.srt=45,tl.col="black",title="Human 2FC DEGs (31)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muDEG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.mouse),method="color",tl.srt=45,tl.col="black",title="Mouse All DEGs (996)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muDEG2FC.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.mouse.2fc),method="color",tl.srt=45,tl.col="black",title="Mouse 2FC DEGs (42)",mar=c(0,0,2,0))
dev.off()






ortholog <- ortholog[order(ortholog[,"Human.gene.name"]),]
ortholog <- ortholog[!duplicated(ortholog$Human.gene.name),]

sc10x.mouse <- readRDS("./analysis/muPrUr_id_fmst.rds")
DefaultAssay(sc10x.mouse) <- "SCT"
sc10x.human <- readRDS("../huPr_PdPb/analysis/huPr_PdPb_id_fmst.rds")
DefaultAssay(sc10x.human) <- "SCT"
bph <- unique(sc10x.human$samples)[startsWith(unique(sc10x.human$samples),"BPH")]
donor <- unique(sc10x.human$samples)[startsWith(unique(sc10x.human$samples),"D")]
sc10x.human$phenotype <- sc10x.human$samples
Idents(sc10x.human) <- "phenotype"
sc10x.human$phenotype[sc10x.human$phenotype %in% bph] <- "BPH"
sc10x.human$phenotype[sc10x.human$phenotype %in% donor] <- "Donor"
Idents(sc10x.human) <- "phenotype"
sc10x.human <- subset(sc10x.human,idents="Donor")

genes.mouse <- rownames(sc10x.mouse)
genes.human <- rownames(sc10x.human)
genes.mouse.filtered <- genes.mouse[genes.mouse %in% ortholog$Gene.name]
genes.human.filtered <- genes.human[genes.human %in% ortholog$Human.gene.name]
genes.mouse.filtered.humanified <- ortholog$Human.gene.name[match(genes.mouse.filtered,ortholog$Gene.name)]
genes.mouse.filtered.humanified <- genes.mouse.filtered.humanified[genes.mouse.filtered.humanified %in% genes.human.filtered]
genes.human.filtered <- genes.human.filtered[genes.human.filtered %in% genes.mouse.filtered.humanified]
genes.mouse.filtered <- ortholog$Gene.name[match(genes.mouse.filtered.humanified,ortholog$Human.gene.name)]
ortholog <- ortholog[ortholog$Gene.name %in% genes.mouse.filtered,]
ortholog <- ortholog[ortholog$Human.gene.name %in% genes.human.filtered,]

Idents(sc10x.mouse) <- "resolution_0.1"
sc10x.mouse <- RenameIdents(sc10x.mouse,"4"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"2"="SM")
sc10x.mouse <- RenameIdents(sc10x.mouse,"3"="Wnt2")
sc10x.mouse <- RenameIdents(sc10x.mouse,"0"="Lgr5")
sc10x.mouse <- RenameIdents(sc10x.mouse,"1"="C3")
sc10x.mouse$id <- Idents(sc10x.mouse)
sc10x.mouse.fib <- sc10x.mouse
data.mouse.fib <- as.data.frame(AverageExpression(sc10x.mouse.fib,assays="SCT",slot="scale.data")$SCT)
data.mouse.fib <- data.mouse.fib[rownames(data.mouse.fib) %in% genes.mouse.filtered,]
rownames(data.mouse.fib) <- ortholog$Human.gene.name[match(rownames(data.mouse.fib),ortholog$Gene.name)]
data.mouse.fib <- data.mouse.fib[ortholog$Human.gene.name,]

Idents(sc10x.human) <- "resolution_0.2"
sc10x.human <- RenameIdents(sc10x.human,"6"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"7"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"2"="dSM")
sc10x.human <- RenameIdents(sc10x.human,"1"="Pericyte")
sc10x.human <- RenameIdents(sc10x.human,"3"="vSM")
sc10x.human <- RenameIdents(sc10x.human,"5"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"0"="Fib_APODn")
sc10x.human <- RenameIdents(sc10x.human,"4"="Fib_APODp")
sc10x.human$ids <- Idents(sc10x.human)
sc10x.human.fib <- sc10x.human
data.human.fib <- as.data.frame(AverageExpression(sc10x.human.fib,assays="SCT",slot="scale.data")$SCT)
data.human.fib <- data.human.fib[rownames(data.human.fib) %in% genes.human.filtered,]
data.human.fib <- data.human.fib[ortholog$Human.gene.name,]

correlation.fib <- cor(data.mouse.fib,data.human.fib,use="complete.obs",method="spearman")

hvg.mouse <- FindVariableFeatures(sc10x.mouse.fib,nfeatures=5000,selection.method="vst",assay="RNA")
hvg.mouse <- VariableFeatures(hvg.mouse,assay="RNA")
#hvg.mouse <- sc10x.mouse@assays$SCT@var.features
hvg.mouse <- hvg.mouse[hvg.mouse %in% genes.mouse.filtered]
hvg.mouse <- ortholog$Human.gene.name[match(hvg.mouse,ortholog$Gene.name)]
hvg.mouse <- hvg.mouse[hvg.mouse %in% genes.human.filtered]
hvg.human <- FindVariableFeatures(sc10x.human.fib,nfeatures=5000,selection.method="vst",assay="RNA")
hvg.human <- VariableFeatures(hvg.human,assay="RNA")
#hvg.human <- sc10x.human@assays$SCT@var.features
hvg.human <- hvg.human[hvg.human %in% ortholog$Human.gene.name]
data.mouse.fib.hvg.human <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg.human,]
data.human.fib.hvg.human <- data.human.fib[rownames(data.human.fib) %in% hvg.human,]
correlation.fib.hvg.human <- cor(data.mouse.fib.hvg.human,data.human.fib.hvg.human,use="complete.obs",method="spearman")

data.mouse.fib.hvg.mouse <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg.mouse,]
data.human.fib.hvg.mouse <- data.human.fib[rownames(data.human.fib) %in% hvg.mouse,]
correlation.fib.hvg.mouse <- cor(data.mouse.fib.hvg.mouse,data.human.fib.hvg.mouse,use="complete.obs",method="spearman")

hvg <- hvg.human[hvg.human %in% hvg.mouse]
data.mouse.fib.hvg <- data.mouse.fib[rownames(data.mouse.fib) %in% hvg,]
data.human.fib.hvg <- data.human.fib[rownames(data.human.fib) %in% hvg,]
correlation.fib.hvg <- cor(data.mouse.fib.hvg,data.human.fib.hvg,use="complete.obs",method="spearman")

deg.human.apodP <- FindMarkers(sc10x.human.fib,ident.1="Fib_APODp",ident.2="Fib_APODn",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.human.apodN <- FindMarkers(sc10x.human.fib,ident.1="Fib_APODn",ident.2="Fib_APODp",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)

deg.human <- c(rownames(deg.human.apodP)[deg.human.apodP$p_val_adj<=0.05],rownames(deg.human.apodN)[deg.human.apodN$p_val_adj<=0.05])
data.mouse.fib.deg.human <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.human,]
data.human.fib.deg.human <- data.human.fib[rownames(data.human.fib) %in% deg.human,]
correlation.fib.deg.human <- cor(data.mouse.fib.deg.human,data.human.fib.deg.human,use="complete.obs")

deg.human.2fc <- c(rownames(deg.human.apodP)[deg.human.apodP$p_val_adj<=0.05 & deg.human.apodP$avg_log2FC>1],rownames(deg.human.apodN)[deg.human.apodN$p_val_adj<=0.05 & deg.human.apodN$avg_log2FC>1])
data.mouse.fib.deg.human.2fc <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.human.2fc,]
data.human.fib.deg.human.2fc <- data.human.fib[rownames(data.human.fib) %in% deg.human.2fc,]
correlation.fib.deg.human.2fc <- cor(data.mouse.fib.deg.human.2fc,data.human.fib.deg.human.2fc,use="complete.obs")

deg.mouse.fib1 <- FindMarkers(sc10x.mouse.fib,ident.1="C3",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.mouse.fib2 <- FindMarkers(sc10x.mouse.fib,ident.1="Lgr5",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)
deg.mouse.fib3 <- FindMarkers(sc10x.mouse.fib,ident.1="Wnt2",assay="SCT",slot="data",logfc.threshold=0,min.pct=0.25,test.use="MAST",only.pos=TRUE)

deg.mouse <- c(rownames(deg.mouse.fib1)[deg.mouse.fib1$p_val_adj<=0.05],rownames(deg.mouse.fib2)[deg.mouse.fib2$p_val_adj<=0.05],rownames(deg.mouse.fib3)[deg.mouse.fib3$p_val_adj<=0.05])
deg.mouse <- deg.mouse[deg.mouse %in% genes.mouse.filtered]
deg.mouse <- ortholog$Human.gene.name[match(deg.mouse,ortholog$Gene.name)]
data.mouse.fib.deg.mouse <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.mouse,]
data.human.fib.deg.mouse <- data.human.fib[rownames(data.human.fib) %in% deg.mouse,]
correlation.fib.deg.mouse <- cor(data.mouse.fib.deg.mouse,data.human.fib.deg.mouse,use="complete.obs")

deg.mouse.2fc <- c(rownames(deg.mouse.fib1)[deg.mouse.fib1$p_val_adj<=0.05 & deg.mouse.fib1$avg_log2FC>1],rownames(deg.mouse.fib2)[deg.mouse.fib2$p_val_adj<=0.05 & deg.mouse.fib2$avg_log2FC>1],rownames(deg.mouse.fib3)[deg.mouse.fib3$p_val_adj<=0.05 & deg.mouse.fib3$avg_log2FC>1])
deg.mouse.2fc <- deg.mouse.2fc[deg.mouse.2fc %in% genes.mouse.filtered]
deg.mouse.2fc <- ortholog$Human.gene.name[match(deg.mouse.2fc,ortholog$Gene.name)]
data.mouse.fib.deg.mouse.2fc <- data.mouse.fib[rownames(data.mouse.fib) %in% deg.mouse.2fc,]
data.human.fib.deg.mouse.2fc <- data.human.fib[rownames(data.human.fib) %in% deg.mouse.2fc,]
correlation.fib.deg.mouse.2fc <- cor(data.mouse.fib.deg.mouse.2fc,data.human.fib.deg.mouse.2fc,use="complete.obs")

jpeg("./analysis/Corr.muhu_fib_all.jpg",width=1000,height=1000)
corrplot(t(correlation.fib),method="color",tl.srt=45,tl.col="black",title="All Genes (14,435)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg.human),method="color",tl.srt=45,tl.col="black",title="Human HVG (3,117)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg.mouse),method="color",tl.srt=45,tl.col="black",title="Mouse HVG (3,454)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_sharedHVG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.hvg),method="color",tl.srt=45,tl.col="black",title="Shared HVG (1,691)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huDEG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.human),method="color",tl.srt=45,tl.col="black",title="Human All DEGs (1,343)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_huDEG2fc.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.human.2fc),method="color",tl.srt=45,tl.col="black",title="Human 2FC DEGs (31)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muDEG.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.mouse),method="color",tl.srt=45,tl.col="black",title="Mouse All DEGs (996)",mar=c(0,0,2,0))
dev.off()
jpeg("./analysis/Corr.muhu_fib_muDEG2FC.jpg",width=1000,height=1000)
corrplot(t(correlation.fib.deg.mouse.2fc),method="color",tl.srt=45,tl.col="black",title="Mouse 2FC DEGs (42)",mar=c(0,0,2,0))
dev.off()

correlation.fib
temp <- (correlation.fib-mean(correlation.fib))/sd(correlation.fib)
jpeg("./analysis/Corr.muhu_fib_all.jpg",width=1000,height=1000)
corrplot(t(temp),method="color",tl.srt=45,tl.col="black",title="ALL Genes",mar=c(0,0,2,0),is.corr=FALSE)
dev.off()